# -*- coding: utf-8 -*-

from flask_login import UserMixin
from itsdangerous import URLSafeTimedSerializer
from constants import SECRET_KEY
from utilities.user_manager import UserManager

login_serializer = URLSafeTimedSerializer(SECRET_KEY)


class User(UserMixin):
    """
    User Class for flask-Login
    """
    def __init__(self, userid, password):
        self.id = userid
        self.password = password

    def get_auth_token(self):
        """
        Encode a secure token for cookie
        """
        data = [str(self.id), self.password]
        return login_serializer.dumps(data)

    @staticmethod
    def get(userid):
        """
        Static method to search the database and see if userid exists.  If it
        does exist then return a User Object.  If not then return None as
        required by Flask-Login.
        """
        current_users = UserManager()
        user = current_users.get_user(userid)
        if user is not None:
            return User(user[1], user[2])
        return None

    def get_id(self):
        return self.id
