# -*- coding: utf-8 -*-
from datetime import datetime
from constants import CLUSTER_TIMEOUT, LATENCY_UPDATE_INTERVAL
import traceback
import eventlet
import sys


def update_statistics_and_latencies_of_all_clusters(cluster_manager, current_app):

    cluster_timeout_interval = CLUSTER_TIMEOUT * 60

    time_to_update_latency = 0
    time_to_update_statistics = 0
    time_to_remove_clusters = cluster_timeout_interval
    update_interval = current_app.config.get("UPDATE_INTERVAL")
    while True:
        try:
            start_time = datetime.now()

            clusters = cluster_manager.get_clusters()

            if time_to_update_statistics <= 0:
                for cluster in list(clusters.values()):
                    cluster.update_statistics()
                update_interval = current_app.config.get("UPDATE_INTERVAL")
                time_to_update_statistics = update_interval
            elif time_to_update_latency <= 0:
                for cluster in list(clusters.values()):
                    cluster.update_latencies()
                time_to_update_latency = LATENCY_UPDATE_INTERVAL
                time_to_remove_clusters -= LATENCY_UPDATE_INTERVAL

            if time_to_remove_clusters <= 0:
                cluster_manager.remove_unused_clusters()
                time_to_remove_clusters = cluster_timeout_interval

            sleep_time = update_interval
            if time_to_update_statistics > time_to_update_latency:
                sleep_time = time_to_update_latency
            else:
                sleep_time = time_to_update_statistics

            end_time = datetime.now()
            time_delta = (end_time - start_time).seconds
            if time_delta > sleep_time:
                sleep_time = 0
            else:
                sleep_time -= time_delta

            eventlet.sleep(sleep_time)
        except Exception:
            sys.stderr.write("Error in update_statistics_of_all_clusters")
            sys.stderr.write((traceback.format_exc()))
            eventlet.sleep(10)

        time_to_update_latency -= sleep_time
        time_to_update_statistics -= sleep_time
